
'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import tournament_service_pb2 as services_dot_tournament__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/tournament_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class TournamentServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetTournament = channel.unary_unary('/parrygg.services.TournamentService/GetTournament', request_serializer=services_dot_tournament__service__pb2.GetTournamentRequest.SerializeToString, response_deserializer=services_dot_tournament__service__pb2.GetTournamentResponse.FromString, _registered_method=True)
        self.GetTournaments = channel.unary_unary('/parrygg.services.TournamentService/GetTournaments', request_serializer=services_dot_tournament__service__pb2.GetTournamentsRequest.SerializeToString, response_deserializer=services_dot_tournament__service__pb2.GetTournamentsResponse.FromString, _registered_method=True)
        self.GetTournamentAttendees = channel.unary_unary('/parrygg.services.TournamentService/GetTournamentAttendees', request_serializer=services_dot_tournament__service__pb2.GetTournamentAttendeesRequest.SerializeToString, response_deserializer=services_dot_tournament__service__pb2.GetTournamentAttendeesResponse.FromString, _registered_method=True)
        self.UpdateTournament = channel.unary_unary('/parrygg.services.TournamentService/UpdateTournament', request_serializer=services_dot_tournament__service__pb2.UpdateTournamentRequest.SerializeToString, response_deserializer=services_dot_tournament__service__pb2.UpdateTournamentResponse.FromString, _registered_method=True)

class TournamentServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def GetTournament(self, request, context):
        'Retrieves a tournament by ID or slug.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTournaments(self, request, context):
        'Retrieves multiple tournaments based on filter criteria.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTournamentAttendees(self, request, context):
        'Retrieves all attendees for a tournament.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTournament(self, request, context):
        'Updates an existing tournament by ID.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_TournamentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetTournament': grpc.unary_unary_rpc_method_handler(servicer.GetTournament, request_deserializer=services_dot_tournament__service__pb2.GetTournamentRequest.FromString, response_serializer=services_dot_tournament__service__pb2.GetTournamentResponse.SerializeToString), 'GetTournaments': grpc.unary_unary_rpc_method_handler(servicer.GetTournaments, request_deserializer=services_dot_tournament__service__pb2.GetTournamentsRequest.FromString, response_serializer=services_dot_tournament__service__pb2.GetTournamentsResponse.SerializeToString), 'GetTournamentAttendees': grpc.unary_unary_rpc_method_handler(servicer.GetTournamentAttendees, request_deserializer=services_dot_tournament__service__pb2.GetTournamentAttendeesRequest.FromString, response_serializer=services_dot_tournament__service__pb2.GetTournamentAttendeesResponse.SerializeToString), 'UpdateTournament': grpc.unary_unary_rpc_method_handler(servicer.UpdateTournament, request_deserializer=services_dot_tournament__service__pb2.UpdateTournamentRequest.FromString, response_serializer=services_dot_tournament__service__pb2.UpdateTournamentResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.TournamentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.TournamentService', rpc_method_handlers)

class TournamentService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def GetTournament(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.TournamentService/GetTournament', services_dot_tournament__service__pb2.GetTournamentRequest.SerializeToString, services_dot_tournament__service__pb2.GetTournamentResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetTournaments(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.TournamentService/GetTournaments', services_dot_tournament__service__pb2.GetTournamentsRequest.SerializeToString, services_dot_tournament__service__pb2.GetTournamentsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetTournamentAttendees(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.TournamentService/GetTournamentAttendees', services_dot_tournament__service__pb2.GetTournamentAttendeesRequest.SerializeToString, services_dot_tournament__service__pb2.GetTournamentAttendeesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdateTournament(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.TournamentService/UpdateTournament', services_dot_tournament__service__pb2.UpdateTournamentRequest.SerializeToString, services_dot_tournament__service__pb2.UpdateTournamentResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/tournament.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..models import image_pb2 as models_dot_image__pb2
from ..models import event_pb2 as models_dot_event__pb2
from ..models import slug_pb2 as models_dot_slug__pb2
from ..models import user_pb2 as models_dot_user__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17models/tournament.proto\x12\x0eparrygg.models\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12models/image.proto\x1a\x12models/event.proto\x1a\x11models/slug.proto\x1a\x11models/user.proto"\xcf\x03\n\nTournament\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nshort_name\x18\x03 \x01(\t\x12\x15\n\rvenue_address\x18\x04 \x01(\t\x12\x15\n\radmin_contact\x18\x07 \x01(\t\x12\x15\n\rcurrency_code\x18\x08 \x01(\t\x12.\n\nstart_date\x18\t \x01(\x0b2\x1a.google.protobuf.Timestamp\x12,\n\x08end_date\x18\n \x01(\x0b2\x1a.google.protobuf.Timestamp\x12.\n\x05state\x18\x0b \x01(\x0e2\x1f.parrygg.models.TournamentState\x12%\n\x06images\x18\x0c \x03(\x0b2\x15.parrygg.models.Image\x12%\n\x06events\x18\r \x03(\x0b2\x15.parrygg.models.Event\x12\x15\n\rnum_attendees\x18\x0e \x01(\x05\x12\x10\n\x08owner_id\x18\x0f \x01(\t\x12#\n\x05slugs\x18\x10 \x03(\x0b2\x14.parrygg.models.Slug\x12\x11\n\tvenue_fee\x18\x11 \x01(\x05\x12\x11\n\ttime_zone\x18\x12 \x01(\t"\xd6\x03\n\x12TournamentMutation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nshort_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rvenue_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\radmin_contact\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rcurrency_code\x18\x07 \x01(\tH\x04\x88\x01\x01\x123\n\nstart_date\x18\x08 \x01(\x0b2\x1a.google.protobuf.TimestampH\x05\x88\x01\x01\x121\n\x08end_date\x18\t \x01(\x0b2\x1a.google.protobuf.TimestampH\x06\x88\x01\x01\x12\x15\n\x08owner_id\x18\n \x01(\tH\x07\x88\x01\x01\x12\x16\n\tvenue_fee\x18\x0b \x01(\x05H\x08\x88\x01\x01\x12\x16\n\ttime_zone\x18\x0c \x01(\tH\t\x88\x01\x01B\x07\n\x05_nameB\r\n\x0b_short_nameB\x10\n\x0e_venue_addressB\x10\n\x0e_admin_contactB\x10\n\x0e_currency_codeB\r\n\x0b_start_dateB\x0b\n\t_end_dateB\x0b\n\t_owner_idB\x0c\n\n_venue_feeB\x0c\n\n_time_zone"K\n\x0bPageContent\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\r\n\x05title\x18\x03 \x01(\t\x12\x12\n\ncontent_md\x18\x04 \x01(\t"x\n\x12MutablePageContent\x12\x12\n\x05index\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05title\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\ncontent_md\x18\x03 \x01(\tH\x02\x88\x01\x01B\x08\n\x06_indexB\x08\n\x06_titleB\r\n\x0b_content_md"\xb1\x01\n\x16TournamentRegistration\x12\x15\n\rtournament_id\x18\x01 \x01(\t\x12\x16\n\x0epaid_venue_fee\x18\x03 \x01(\x08\x12>\n\x13event_registrations\x18\x04 \x03(\x0b2!.parrygg.models.EventRegistration\x12"\n\x04user\x18\x05 \x01(\x0b2\x14.parrygg.models.UserJ\x04\x08\x02\x10\x03"\x9e\x01\n\x1eTournamentRegistrationMutation\x12\x1b\n\x0epaid_venue_fee\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12F\n\x13event_registrations\x18\x02 \x03(\x0b2).parrygg.models.EventRegistrationMutationB\x11\n\x0f_paid_venue_feeJ\x04\x08\x03\x10\x04"|\n#BatchTournamentRegistrationMutation\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12D\n\x0cregistration\x18\x02 \x01(\x0b2..parrygg.models.TournamentRegistrationMutation"i\n\x12TournamentAttendee\x12"\n\x04user\x18\x01 \x01(\x0b2\x14.parrygg.models.User\x12/\n\x06events\x18\x02 \x03(\x0b2\x1f.parrygg.models.EventAttendance"M\n\x14TournamentIdentifier\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x12\x19\n\x0ftournament_slug\x18\x02 \x01(\tH\x00B\x0c\n\nidentifier"d\n\x1dTournamentPermissionsMetadata\x12C\n\x15tournament_permission\x18\x01 \x01(\x0e2$.parrygg.models.TournamentPermission*\xaf\x01\n\x0fTournamentState\x12 \n\x1cTOURNAMENT_STATE_UNSPECIFIED\x10\x00\x12\x1c\n\x18TOURNAMENT_STATE_PENDING\x10\x01\x12\x1a\n\x16TOURNAMENT_STATE_READY\x10\x02\x12 \n\x1cTOURNAMENT_STATE_IN_PROGRESS\x10\x03\x12\x1e\n\x1aTOURNAMENT_STATE_COMPLETED\x10\x04*\x91\x01\n\x14TournamentPermission\x12 \n\x1cPERMISSION_LEVEL_UNSPECIFIED\x10\x00\x12\x1a\n\x16PERMISSION_LEVEL_ADMIN\x10\x01\x12\x1c\n\x18PERMISSION_LEVEL_MANAGER\x10\x02\x12\x1d\n\x19PERMISSION_LEVEL_REPORTER\x10\x03B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.tournament_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_TOURNAMENTSTATE']._serialized_start = 2048
    _globals['_TOURNAMENTSTATE']._serialized_end = 2223
    _globals['_TOURNAMENTPERMISSION']._serialized_start = 2226
    _globals['_TOURNAMENTPERMISSION']._serialized_end = 2371
    _globals['_TOURNAMENT']._serialized_start = 155
    _globals['_TOURNAMENT']._serialized_end = 618
    _globals['_TOURNAMENTMUTATION']._serialized_start = 621
    _globals['_TOURNAMENTMUTATION']._serialized_end = 1091
    _globals['_PAGECONTENT']._serialized_start = 1093
    _globals['_PAGECONTENT']._serialized_end = 1168
    _globals['_MUTABLEPAGECONTENT']._serialized_start = 1170
    _globals['_MUTABLEPAGECONTENT']._serialized_end = 1290
    _globals['_TOURNAMENTREGISTRATION']._serialized_start = 1293
    _globals['_TOURNAMENTREGISTRATION']._serialized_end = 1470
    _globals['_TOURNAMENTREGISTRATIONMUTATION']._serialized_start = 1473
    _globals['_TOURNAMENTREGISTRATIONMUTATION']._serialized_end = 1631
    _globals['_BATCHTOURNAMENTREGISTRATIONMUTATION']._serialized_start = 1633
    _globals['_BATCHTOURNAMENTREGISTRATIONMUTATION']._serialized_end = 1757
    _globals['_TOURNAMENTATTENDEE']._serialized_start = 1759
    _globals['_TOURNAMENTATTENDEE']._serialized_end = 1864
    _globals['_TOURNAMENTIDENTIFIER']._serialized_start = 1866
    _globals['_TOURNAMENTIDENTIFIER']._serialized_end = 1943
    _globals['_TOURNAMENTPERMISSIONSMETADATA']._serialized_start = 1945
    _globals['_TOURNAMENTPERMISSIONSMETADATA']._serialized_end = 2045




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/game.proto')
_sym_db = _symbol_database.Default()
from ..models import image_pb2 as models_dot_image__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11models/game.proto\x12\x0eparrygg.models\x1a\x12models/image.proto"\\\n\x04Game\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bdescription\x18\x03 \x01(\t\x12%\n\x06images\x18\x04 \x03(\x0b2\x15.parrygg.models.Image"\x1c\n\x0cGameMutation\x12\x0c\n\x04name\x18\x01 \x01(\tB\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.game_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_GAME']._serialized_start = 57
    _globals['_GAME']._serialized_end = 149
    _globals['_GAMEMUTATION']._serialized_start = 151
    _globals['_GAMEMUTATION']._serialized_end = 179




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/hierarchy.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16models/hierarchy.proto\x12\x0eparrygg.models"V\n\x04Path\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e2\x18.parrygg.models.PathType\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04slug\x18\x04 \x01(\t"<\n\rEventSlugPath\x12\x17\n\x0ftournament_slug\x18\x01 \x01(\t\x12\x12\n\nevent_slug\x18\x02 \x01(\t"P\n\rPhaseSlugPath\x12\x17\n\x0ftournament_slug\x18\x01 \x01(\t\x12\x12\n\nevent_slug\x18\x02 \x01(\t\x12\x12\n\nphase_slug\x18\x03 \x01(\t"h\n\x0fBracketSlugPath\x12\x17\n\x0ftournament_slug\x18\x01 \x01(\t\x12\x12\n\nevent_slug\x18\x02 \x01(\t\x12\x12\n\nphase_slug\x18\x03 \x01(\t\x12\x14\n\x0cbracket_slug\x18\x04 \x01(\t"0\n\tHierarchy\x12#\n\x05paths\x18\x01 \x03(\x0b2\x14.parrygg.models.Path*e\n\x08PathType\x12\x18\n\x14PATH_TYPE_TOURNAMENT\x10\x00\x12\x13\n\x0fPATH_TYPE_EVENT\x10\x01\x12\x13\n\x0fPATH_TYPE_PHASE\x10\x02\x12\x15\n\x11PATH_TYPE_BRACKET\x10\x03B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.hierarchy_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_PATHTYPE']._serialized_start = 430
    _globals['_PATHTYPE']._serialized_end = 531
    _globals['_PATH']._serialized_start = 42
    _globals['_PATH']._serialized_end = 128
    _globals['_EVENTSLUGPATH']._serialized_start = 130
    _globals['_EVENTSLUGPATH']._serialized_end = 190
    _globals['_PHASESLUGPATH']._serialized_start = 192
    _globals['_PHASESLUGPATH']._serialized_end = 272
    _globals['_BRACKETSLUGPATH']._serialized_start = 274
    _globals['_BRACKETSLUGPATH']._serialized_end = 378
    _globals['_HIERARCHY']._serialized_start = 380
    _globals['_HIERARCHY']._serialized_end = 428




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/entrant_service.proto')
_sym_db = _symbol_database.Default()
from ..models import entrant_pb2 as models_dot_entrant__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/entrant_service.proto\x12\x10parrygg.services\x1a\x14models/entrant.proto">\n\x16GetEventEntrantRequest\x12\x10\n\x08event_id\x18\x01 \x01(\t\x12\x12\n\nentrant_id\x18\x02 \x01(\t"N\n\x17GetEventEntrantResponse\x123\n\revent_entrant\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant"A\n\x19CreateEventEntrantRequest\x12\x10\n\x08event_id\x18\x01 \x01(\t\x12\x12\n\nentrant_id\x18\x02 \x01(\t"Q\n\x1aCreateEventEntrantResponse\x123\n\revent_entrant\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant"~\n\x19UpdateEventEntrantRequest\x12\x10\n\x08event_id\x18\x01 \x01(\t\x12\x12\n\nentrant_id\x18\x02 \x01(\t\x12;\n\revent_entrant\x18\x03 \x01(\x0b2$.parrygg.models.EventEntrantMutation"Q\n\x1aUpdateEventEntrantResponse\x123\n\revent_entrant\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant"A\n\x19DeleteEventEntrantRequest\x12\x10\n\x08event_id\x18\x01 \x01(\t\x12\x12\n\nentrant_id\x18\x02 \x01(\t"\x1c\n\x1aDeleteEventEntrantResponse"a\n\x1dRemoveFromEventEntrantRequest\x12\x18\n\x10event_entrant_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x15\n\rkeep_in_event\x18\x03 \x01(\x08"\x8f\x01\n\x1eRemoveFromEventEntrantResponse\x123\n\revent_entrant\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant\x128\n\x12removed_free_agent\x18\x02 \x01(\x0b2\x1c.parrygg.models.EventEntrant"6\n\x1aDisbandEventEntrantRequest\x12\x18\n\x10event_entrant_id\x18\x01 \x01(\t"R\n\x1bDisbandEventEntrantResponse\x123\n\revent_entrant\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant"Z\n\x11CreateTeamRequest\x12\x10\n\x08event_id\x18\x01 \x01(\t\x123\n\rteam_mutation\x18\x02 \x01(\x0b2\x1c.parrygg.models.TeamMutation"@\n\x12CreateTeamResponse\x12*\n\x04team\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant"T\n\x11UpdateTeamRequest\x12\n\n\x02id\x18\x01 \x01(\t\x123\n\rteam_mutation\x18\x02 \x01(\x0b2\x1c.parrygg.models.TeamMutation"@\n\x12UpdateTeamResponse\x12*\n\x04team\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant2\xfe\x06\n\x0eEntrantService\x12h\n\x0fGetEventEntrant\x12(.parrygg.services.GetEventEntrantRequest\x1a).parrygg.services.GetEventEntrantResponse"\x00\x12q\n\x12CreateEventEntrant\x12+.parrygg.services.CreateEventEntrantRequest\x1a,.parrygg.services.CreateEventEntrantResponse"\x00\x12q\n\x12UpdateEventEntrant\x12+.parrygg.services.UpdateEventEntrantRequest\x1a,.parrygg.services.UpdateEventEntrantResponse"\x00\x12q\n\x12DeleteEventEntrant\x12+.parrygg.services.DeleteEventEntrantRequest\x1a,.parrygg.services.DeleteEventEntrantResponse"\x00\x12}\n\x16RemoveFromEventEntrant\x12/.parrygg.services.RemoveFromEventEntrantRequest\x1a0.parrygg.services.RemoveFromEventEntrantResponse"\x00\x12t\n\x13DisbandEventEntrant\x12,.parrygg.services.DisbandEventEntrantRequest\x1a-.parrygg.services.DisbandEventEntrantResponse"\x00\x12Y\n\nCreateTeam\x12#.parrygg.services.CreateTeamRequest\x1a$.parrygg.services.CreateTeamResponse"\x00\x12Y\n\nUpdateTeam\x12#.parrygg.services.UpdateTeamRequest\x1a$.parrygg.services.UpdateTeamResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.entrant_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETEVENTENTRANTREQUEST']._serialized_start = 74
    _globals['_GETEVENTENTRANTREQUEST']._serialized_end = 136
    _globals['_GETEVENTENTRANTRESPONSE']._serialized_start = 138
    _globals['_GETEVENTENTRANTRESPONSE']._serialized_end = 216
    _globals['_CREATEEVENTENTRANTREQUEST']._serialized_start = 218
    _globals['_CREATEEVENTENTRANTREQUEST']._serialized_end = 283
    _globals['_CREATEEVENTENTRANTRESPONSE']._serialized_start = 285
    _globals['_CREATEEVENTENTRANTRESPONSE']._serialized_end = 366
    _globals['_UPDATEEVENTENTRANTREQUEST']._serialized_start = 368
    _globals['_UPDATEEVENTENTRANTREQUEST']._serialized_end = 494
    _globals['_UPDATEEVENTENTRANTRESPONSE']._serialized_start = 496
    _globals['_UPDATEEVENTENTRANTRESPONSE']._serialized_end = 577
    _globals['_DELETEEVENTENTRANTREQUEST']._serialized_start = 579
    _globals['_DELETEEVENTENTRANTREQUEST']._serialized_end = 644
    _globals['_DELETEEVENTENTRANTRESPONSE']._serialized_start = 646
    _globals['_DELETEEVENTENTRANTRESPONSE']._serialized_end = 674
    _globals['_REMOVEFROMEVENTENTRANTREQUEST']._serialized_start = 676
    _globals['_REMOVEFROMEVENTENTRANTREQUEST']._serialized_end = 773
    _globals['_REMOVEFROMEVENTENTRANTRESPONSE']._serialized_start = 776
    _globals['_REMOVEFROMEVENTENTRANTRESPONSE']._serialized_end = 919
    _globals['_DISBANDEVENTENTRANTREQUEST']._serialized_start = 921
    _globals['_DISBANDEVENTENTRANTREQUEST']._serialized_end = 975
    _globals['_DISBANDEVENTENTRANTRESPONSE']._serialized_start = 977
    _globals['_DISBANDEVENTENTRANTRESPONSE']._serialized_end = 1059
    _globals['_CREATETEAMREQUEST']._serialized_start = 1061
    _globals['_CREATETEAMREQUEST']._serialized_end = 1151
    _globals['_CREATETEAMRESPONSE']._serialized_start = 1153
    _globals['_CREATETEAMRESPONSE']._serialized_end = 1217
    _globals['_UPDATETEAMREQUEST']._serialized_start = 1219
    _globals['_UPDATETEAMREQUEST']._serialized_end = 1303
    _globals['_UPDATETEAMRESPONSE']._serialized_start = 1305
    _globals['_UPDATETEAMRESPONSE']._serialized_end = 1369
    _globals['_ENTRANTSERVICE']._serialized_start = 1372
    _globals['_ENTRANTSERVICE']._serialized_end = 2266




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/user_service.proto')
_sym_db = _symbol_database.Default()
from ..models import user_pb2 as models_dot_user__pb2
from ..models import image_pb2 as models_dot_image__pb2
from ..models import filter_pb2 as models_dot_filter__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bservices/user_service.proto\x12\x10parrygg.services\x1a\x11models/user.proto\x1a\x12models/image.proto\x1a\x13models/filter.proto",\n\x0eGetUserRequest\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00B\x0c\n\nidentifier"5\n\x0fGetUserResponse\x12"\n\x04user\x18\x01 \x01(\x0b2\x14.parrygg.models.User">\n\x0fGetUsersRequest\x12+\n\x06filter\x18\x01 \x01(\x0b2\x1b.parrygg.models.UsersFilter"7\n\x10GetUsersResponse\x12#\n\x05users\x18\x01 \x03(\x0b2\x14.parrygg.models.User"J\n\x11UpdateUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x04user\x18\x02 \x01(\x0b2\x1b.parrygg.models.MutableUser"8\n\x12UpdateUserResponse\x12"\n\x04user\x18\x01 \x01(\x0b2\x14.parrygg.models.User2\x8f\x02\n\x0bUserService\x12P\n\x07GetUser\x12 .parrygg.services.GetUserRequest\x1a!.parrygg.services.GetUserResponse"\x00\x12S\n\x08GetUsers\x12!.parrygg.services.GetUsersRequest\x1a".parrygg.services.GetUsersResponse"\x00\x12Y\n\nUpdateUser\x12#.parrygg.services.UpdateUserRequest\x1a$.parrygg.services.UpdateUserResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.user_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETUSERREQUEST']._serialized_start = 109
    _globals['_GETUSERREQUEST']._serialized_end = 153
    _globals['_GETUSERRESPONSE']._serialized_start = 155
    _globals['_GETUSERRESPONSE']._serialized_end = 208
    _globals['_GETUSERSREQUEST']._serialized_start = 210
    _globals['_GETUSERSREQUEST']._serialized_end = 272
    _globals['_GETUSERSRESPONSE']._serialized_start = 274
    _globals['_GETUSERSRESPONSE']._serialized_end = 329
    _globals['_UPDATEUSERREQUEST']._serialized_start = 331
    _globals['_UPDATEUSERREQUEST']._serialized_end = 405
    _globals['_UPDATEUSERRESPONSE']._serialized_start = 407
    _globals['_UPDATEUSERRESPONSE']._serialized_end = 463
    _globals['_USERSERVICE']._serialized_start = 466
    _globals['_USERSERVICE']._serialized_end = 737




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/match_service.proto')
_sym_db = _symbol_database.Default()
from ..models import bracket_pb2 as models_dot_bracket__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cservices/match_service.proto\x12\x10parrygg.services\x1a\x14models/bracket.proto"\x1d\n\x0fGetMatchRequest\x12\n\n\x02id\x18\x01 \x01(\t"8\n\x10GetMatchResponse\x12$\n\x05match\x18\x01 \x01(\x0b2\x15.parrygg.models.Match"P\n\x15SetMatchResultRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x06result\x18\x02 \x01(\x0b2\x1b.parrygg.models.MatchResult"\x18\n\x16SetMatchResultResponse"\x1f\n\x11ResetMatchRequest\x12\n\n\x02id\x18\x01 \x01(\t"\x14\n\x12ResetMatchResponse"\x1f\n\x11StartMatchRequest\x12\n\n\x02id\x18\x01 \x01(\t"\x14\n\x12StartMatchResponse2\x80\x03\n\x0cMatchService\x12S\n\x08GetMatch\x12!.parrygg.services.GetMatchRequest\x1a".parrygg.services.GetMatchResponse"\x00\x12e\n\x0eSetMatchResult\x12\'.parrygg.services.SetMatchResultRequest\x1a(.parrygg.services.SetMatchResultResponse"\x00\x12Y\n\nStartMatch\x12#.parrygg.services.StartMatchRequest\x1a$.parrygg.services.StartMatchResponse"\x00\x12Y\n\nResetMatch\x12#.parrygg.services.ResetMatchRequest\x1a$.parrygg.services.ResetMatchResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.match_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETMATCHREQUEST']._serialized_start = 72
    _globals['_GETMATCHREQUEST']._serialized_end = 101
    _globals['_GETMATCHRESPONSE']._serialized_start = 103
    _globals['_GETMATCHRESPONSE']._serialized_end = 159
    _globals['_SETMATCHRESULTREQUEST']._serialized_start = 161
    _globals['_SETMATCHRESULTREQUEST']._serialized_end = 241
    _globals['_SETMATCHRESULTRESPONSE']._serialized_start = 243
    _globals['_SETMATCHRESULTRESPONSE']._serialized_end = 267
    _globals['_RESETMATCHREQUEST']._serialized_start = 269
    _globals['_RESETMATCHREQUEST']._serialized_end = 300
    _globals['_RESETMATCHRESPONSE']._serialized_start = 302
    _globals['_RESETMATCHRESPONSE']._serialized_end = 322
    _globals['_STARTMATCHREQUEST']._serialized_start = 324
    _globals['_STARTMATCHREQUEST']._serialized_end = 355
    _globals['_STARTMATCHRESPONSE']._serialized_start = 357
    _globals['_STARTMATCHRESPONSE']._serialized_end = 377
    _globals['_MATCHSERVICE']._serialized_start = 380
    _globals['_MATCHSERVICE']._serialized_end = 764




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import page_content_service_pb2 as services_dot_page__content__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/page_content_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class PageContentServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetPageContents = channel.unary_unary('/parrygg.services.PageContentService/GetPageContents', request_serializer=services_dot_page__content__service__pb2.GetPageContentsRequest.SerializeToString, response_deserializer=services_dot_page__content__service__pb2.GetPageContentsResponse.FromString, _registered_method=True)
        self.CreatePageContent = channel.unary_unary('/parrygg.services.PageContentService/CreatePageContent', request_serializer=services_dot_page__content__service__pb2.CreatePageContentRequest.SerializeToString, response_deserializer=services_dot_page__content__service__pb2.CreatePageContentResponse.FromString, _registered_method=True)
        self.UpdatePageContent = channel.unary_unary('/parrygg.services.PageContentService/UpdatePageContent', request_serializer=services_dot_page__content__service__pb2.UpdatePageContentRequest.SerializeToString, response_deserializer=services_dot_page__content__service__pb2.UpdatePageContentResponse.FromString, _registered_method=True)
        self.DeletePageContent = channel.unary_unary('/parrygg.services.PageContentService/DeletePageContent', request_serializer=services_dot_page__content__service__pb2.DeletePageContentRequest.SerializeToString, response_deserializer=services_dot_page__content__service__pb2.DeletePageContentResponse.FromString, _registered_method=True)

class PageContentServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def GetPageContents(self, request, context):
        'Retrieves all page contents for a tournament by ID or identifier.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePageContent(self, request, context):
        'Creates new page content for a tournament.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePageContent(self, request, context):
        'Updates existing page content by ID.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePageContent(self, request, context):
        'Deletes page content by ID.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_PageContentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetPageContents': grpc.unary_unary_rpc_method_handler(servicer.GetPageContents, request_deserializer=services_dot_page__content__service__pb2.GetPageContentsRequest.FromString, response_serializer=services_dot_page__content__service__pb2.GetPageContentsResponse.SerializeToString), 'CreatePageContent': grpc.unary_unary_rpc_method_handler(servicer.CreatePageContent, request_deserializer=services_dot_page__content__service__pb2.CreatePageContentRequest.FromString, response_serializer=services_dot_page__content__service__pb2.CreatePageContentResponse.SerializeToString), 'UpdatePageContent': grpc.unary_unary_rpc_method_handler(servicer.UpdatePageContent, request_deserializer=services_dot_page__content__service__pb2.UpdatePageContentRequest.FromString, response_serializer=services_dot_page__content__service__pb2.UpdatePageContentResponse.SerializeToString), 'DeletePageContent': grpc.unary_unary_rpc_method_handler(servicer.DeletePageContent, request_deserializer=services_dot_page__content__service__pb2.DeletePageContentRequest.FromString, response_serializer=services_dot_page__content__service__pb2.DeletePageContentResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.PageContentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.PageContentService', rpc_method_handlers)

class PageContentService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def GetPageContents(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.PageContentService/GetPageContents', services_dot_page__content__service__pb2.GetPageContentsRequest.SerializeToString, services_dot_page__content__service__pb2.GetPageContentsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def CreatePageContent(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.PageContentService/CreatePageContent', services_dot_page__content__service__pb2.CreatePageContentRequest.SerializeToString, services_dot_page__content__service__pb2.CreatePageContentResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdatePageContent(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.PageContentService/UpdatePageContent', services_dot_page__content__service__pb2.UpdatePageContentRequest.SerializeToString, services_dot_page__content__service__pb2.UpdatePageContentResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def DeletePageContent(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.PageContentService/DeletePageContent', services_dot_page__content__service__pb2.DeletePageContentRequest.SerializeToString, services_dot_page__content__service__pb2.DeletePageContentResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/bracket.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..models import entrant_pb2 as models_dot_entrant__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14models/bracket.proto\x12\x0eparrygg.models\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14models/entrant.proto"\xda\x02\n\x07Bracket\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x05state\x18\x02 \x01(\x0e2\x1c.parrygg.models.BracketState\x12&\n\x07matches\x18\x03 \x03(\x0b2\x15.parrygg.models.Match\x121\n\x0cprogressions\x18\x04 \x03(\x0b2\x1b.parrygg.models.Progression\x12\r\n\x05index\x18\x05 \x01(\x05\x12#\n\x05seeds\x18\x06 \x03(\x0b2\x14.parrygg.models.Seed\x12.\n\nupdated_at\x18\x07 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0c\n\x04slug\x18\t \x01(\t\x12\x10\n\x08checksum\x18\n \x01(\t\x12)\n\x04type\x18\x0b \x01(\x0e2\x1b.parrygg.models.BracketType"\xb2\x03\n\x05Match\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nidentifier\x18\x02 \x01(\t\x12\r\n\x05round\x18\x05 \x01(\x05\x12\x14\n\x0cwinners_side\x18\x06 \x01(\x08\x12\x14\n\x0cgrand_finals\x18\x07 \x01(\x08\x12\x1c\n\x0fprev_match_id_1\x18\x08 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0fprev_match_id_2\x18\t \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10winners_match_id\x18\n \x01(\tH\x02\x88\x01\x01\x12\x1c\n\x0flosers_match_id\x18\x0b \x01(\tH\x03\x88\x01\x01\x12)\n\x05state\x18\x0c \x01(\x0e2\x1a.parrygg.models.MatchState\x12#\n\x05slots\x18\r \x03(\x0b2\x14.parrygg.models.Slot\x124\n\x10state_updated_at\x18\x0e \x01(\x0b2\x1a.google.protobuf.TimestampB\x12\n\x10_prev_match_id_1B\x12\n\x10_prev_match_id_2B\x13\n\x11_winners_match_idB\x12\n\x10_losers_match_id"E\n\x0bMatchResult\x126\n\x05slots\x18\x01 \x03(\x0b2\'.parrygg.models.MatchResultSlotMutation"~\n\x17MatchResultSlotMutation\x12\x0c\n\x04slot\x18\x01 \x01(\x05\x12\x12\n\x05score\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12-\n\x05state\x18\x03 \x01(\x0e2\x19.parrygg.models.SlotStateH\x01\x88\x01\x01B\x08\n\x06_scoreB\x08\n\x06_state"\xb0\x01\n\x0bProgression\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08match_id\x18\x02 \x01(\t\x12\x17\n\x0ftarget_phase_id\x18\x03 \x01(\t\x12\x0f\n\x07seed_id\x18\x04 \x01(\t\x12\x18\n\x10origin_placement\x18\x05 \x01(\x05\x12\x13\n\x0borigin_seed\x18\x06 \x01(\x05\x12\x14\n\x0cmatch_winner\x18\x07 \x01(\x08\x12\x14\n\x0cwinners_side\x18\x08 \x01(\x08"q\n\x04Slot\x12\x0c\n\x04slot\x18\x01 \x01(\x05\x12\x0f\n\x07seed_id\x18\x02 \x01(\t\x12\x11\n\tplacement\x18\x03 \x01(\x05\x12\r\n\x05score\x18\x04 \x01(\x01\x12(\n\x05state\x18\x05 \x01(\x0e2\x19.parrygg.models.SlotState"U\n\x04Seed\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04seed\x18\x02 \x01(\x05\x123\n\revent_entrant\x18\x03 \x01(\x0b2\x1c.parrygg.models.EventEntrant"*\n\x0cSeedMutation\x12\x11\n\x04seed\x18\x02 \x01(\x05H\x00\x88\x01\x01B\x07\n\x05_seed"f\n\rBracketSlugId\x12\x17\n\x0ftournament_slug\x18\x01 \x01(\t\x12\x12\n\nevent_slug\x18\x02 \x01(\t\x12\x12\n\nphase_slug\x18\x03 \x01(\t\x12\x14\n\x0cbracket_slug\x18\x04 \x01(\t*\x93\x01\n\x0bBracketType\x12\x1c\n\x18BRACKET_TYPE_UNSPECIFIED\x10\x00\x12#\n\x1fBRACKET_TYPE_SINGLE_ELIMINATION\x10\x01\x12#\n\x1fBRACKET_TYPE_DOUBLE_ELIMINATION\x10\x02\x12\x1c\n\x18BRACKET_TYPE_ROUND_ROBIN\x10\x03*\x9d\x01\n\x0cBracketState\x12\x1d\n\x19BRACKET_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15BRACKET_STATE_PENDING\x10\x01\x12\x17\n\x13BRACKET_STATE_READY\x10\x02\x12\x1d\n\x19BRACKET_STATE_IN_PROGRESS\x10\x03\x12\x1b\n\x17BRACKET_STATE_COMPLETED\x10\x04*\x91\x01\n\nMatchState\x12\x1b\n\x17MATCH_STATE_UNSPECIFIED\x10\x00\x12\x17\n\x13MATCH_STATE_PENDING\x10\x01\x12\x15\n\x11MATCH_STATE_READY\x10\x02\x12\x1b\n\x17MATCH_STATE_IN_PROGRESS\x10\x03\x12\x19\n\x15MATCH_STATE_COMPLETED\x10\x04*\xac\x01\n\x13ProgressionBehavior\x12$\n PROGRESSION_BEHAVIOR_UNSPECIFIED\x10\x00\x12 \n\x1cPROGRESSION_BEHAVIOR_NATURAL\x10\x01\x12&\n"PROGRESSION_BEHAVIOR_FORCE_WINNERS\x10\x02\x12%\n!PROGRESSION_BEHAVIOR_FORCE_LOSERS\x10\x03*~\n\tSlotState\x12\x1a\n\x16SLOT_STATE_UNSPECIFIED\x10\x00\x12\x16\n\x12SLOT_STATE_PENDING\x10\x01\x12\x16\n\x12SLOT_STATE_NUMERIC\x10\x02\x12\x11\n\rSLOT_STATE_DQ\x10\x03\x12\x12\n\x0eSLOT_STATE_BYE\x10\x04B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.bracket_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_BRACKETTYPE']._serialized_start = 1610
    _globals['_BRACKETTYPE']._serialized_end = 1757
    _globals['_BRACKETSTATE']._serialized_start = 1760
    _globals['_BRACKETSTATE']._serialized_end = 1917
    _globals['_MATCHSTATE']._serialized_start = 1920
    _globals['_MATCHSTATE']._serialized_end = 2065
    _globals['_PROGRESSIONBEHAVIOR']._serialized_start = 2068
    _globals['_PROGRESSIONBEHAVIOR']._serialized_end = 2240
    _globals['_SLOTSTATE']._serialized_start = 2242
    _globals['_SLOTSTATE']._serialized_end = 2368
    _globals['_BRACKET']._serialized_start = 96
    _globals['_BRACKET']._serialized_end = 442
    _globals['_MATCH']._serialized_start = 445
    _globals['_MATCH']._serialized_end = 879
    _globals['_MATCHRESULT']._serialized_start = 881
    _globals['_MATCHRESULT']._serialized_end = 950
    _globals['_MATCHRESULTSLOTMUTATION']._serialized_start = 952
    _globals['_MATCHRESULTSLOTMUTATION']._serialized_end = 1078
    _globals['_PROGRESSION']._serialized_start = 1081
    _globals['_PROGRESSION']._serialized_end = 1257
    _globals['_SLOT']._serialized_start = 1259
    _globals['_SLOT']._serialized_end = 1372
    _globals['_SEED']._serialized_start = 1374
    _globals['_SEED']._serialized_end = 1459
    _globals['_SEEDMUTATION']._serialized_start = 1461
    _globals['_SEEDMUTATION']._serialized_end = 1503
    _globals['_BRACKETSLUGID']._serialized_start = 1505
    _globals['_BRACKETSLUGID']._serialized_end = 1607




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/tournament_service.proto')
_sym_db = _symbol_database.Default()
from ..models import tournament_pb2 as models_dot_tournament__pb2
from ..models import image_pb2 as models_dot_image__pb2
from ..models import filter_pb2 as models_dot_filter__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!services/tournament_service.proto\x12\x10parrygg.services\x1a\x17models/tournament.proto\x1a\x12models/image.proto\x1a\x13models/filter.proto"\x92\x01\n\x14GetTournamentRequest\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x12\x19\n\x0ftournament_slug\x18\x02 \x01(\tH\x00\x12C\n\x15tournament_identifier\x18\x03 \x01(\x0b2$.parrygg.models.TournamentIdentifierB\x0c\n\nidentifier"G\n\x15GetTournamentResponse\x12.\n\ntournament\x18\x01 \x01(\x0b2\x1a.parrygg.models.Tournament"\xa2\x01\n\x17UpdateTournamentRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12C\n\x15tournament_identifier\x18\x03 \x01(\x0b2$.parrygg.models.TournamentIdentifier\x126\n\ntournament\x18\x02 \x01(\x0b2".parrygg.models.TournamentMutation"J\n\x18UpdateTournamentResponse\x12.\n\nTournament\x18\x01 \x01(\x0b2\x1a.parrygg.models.Tournament"3\n\x15GetTournamentsOptions\x12\x1a\n\x12return_permissions\x18\x01 \x01(\x08"\x84\x01\n\x15GetTournamentsRequest\x121\n\x06filter\x18\x01 \x01(\x0b2!.parrygg.models.TournamentsFilter\x128\n\x07options\x18\x02 \x01(\x0b2\'.parrygg.services.GetTournamentsOptions"\x9b\x02\n\x16GetTournamentsResponse\x12/\n\x0btournaments\x18\x01 \x03(\x0b2\x1a.parrygg.models.Tournament\x12c\n\x16tournament_permissions\x18\x02 \x03(\x0b2C.parrygg.services.GetTournamentsResponse.TournamentPermissionsEntry\x1ak\n\x1aTournamentPermissionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b2-.parrygg.models.TournamentPermissionsMetadata:\x028\x01"{\n\x1dGetTournamentAttendeesRequest\x12\x15\n\rtournament_id\x18\x01 \x01(\t\x12C\n\x15tournament_identifier\x18\x02 \x01(\x0b2$.parrygg.models.TournamentIdentifier"W\n\x1eGetTournamentAttendeesResponse\x125\n\tattendees\x18\x01 \x03(\x0b2".parrygg.models.TournamentAttendee2\xca\x03\n\x11TournamentService\x12b\n\rGetTournament\x12&.parrygg.services.GetTournamentRequest\x1a\'.parrygg.services.GetTournamentResponse"\x00\x12e\n\x0eGetTournaments\x12\'.parrygg.services.GetTournamentsRequest\x1a(.parrygg.services.GetTournamentsResponse"\x00\x12}\n\x16GetTournamentAttendees\x12/.parrygg.services.GetTournamentAttendeesRequest\x1a0.parrygg.services.GetTournamentAttendeesResponse"\x00\x12k\n\x10UpdateTournament\x12).parrygg.services.UpdateTournamentRequest\x1a*.parrygg.services.UpdateTournamentResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.tournament_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETTOURNAMENTSRESPONSE_TOURNAMENTPERMISSIONSENTRY']._loaded_options = None
    _globals['_GETTOURNAMENTSRESPONSE_TOURNAMENTPERMISSIONSENTRY']._serialized_options = b'8\x01'
    _globals['_GETTOURNAMENTREQUEST']._serialized_start = 122
    _globals['_GETTOURNAMENTREQUEST']._serialized_end = 268
    _globals['_GETTOURNAMENTRESPONSE']._serialized_start = 270
    _globals['_GETTOURNAMENTRESPONSE']._serialized_end = 341
    _globals['_UPDATETOURNAMENTREQUEST']._serialized_start = 344
    _globals['_UPDATETOURNAMENTREQUEST']._serialized_end = 506
    _globals['_UPDATETOURNAMENTRESPONSE']._serialized_start = 508
    _globals['_UPDATETOURNAMENTRESPONSE']._serialized_end = 582
    _globals['_GETTOURNAMENTSOPTIONS']._serialized_start = 584
    _globals['_GETTOURNAMENTSOPTIONS']._serialized_end = 635
    _globals['_GETTOURNAMENTSREQUEST']._serialized_start = 638
    _globals['_GETTOURNAMENTSREQUEST']._serialized_end = 770
    _globals['_GETTOURNAMENTSRESPONSE']._serialized_start = 773
    _globals['_GETTOURNAMENTSRESPONSE']._serialized_end = 1056
    _globals['_GETTOURNAMENTSRESPONSE_TOURNAMENTPERMISSIONSENTRY']._serialized_start = 949
    _globals['_GETTOURNAMENTSRESPONSE_TOURNAMENTPERMISSIONSENTRY']._serialized_end = 1056
    _globals['_GETTOURNAMENTATTENDEESREQUEST']._serialized_start = 1058
    _globals['_GETTOURNAMENTATTENDEESREQUEST']._serialized_end = 1181
    _globals['_GETTOURNAMENTATTENDEESRESPONSE']._serialized_start = 1183
    _globals['_GETTOURNAMENTATTENDEESRESPONSE']._serialized_end = 1270
    _globals['_TOURNAMENTSERVICE']._serialized_start = 1273
    _globals['_TOURNAMENTSERVICE']._serialized_end = 1731




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/bracket_service.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..models import bracket_pb2 as models_dot_bracket__pb2
from ..models import entrant_pb2 as models_dot_entrant__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/bracket_service.proto\x12\x10parrygg.services\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14models/bracket.proto\x1a\x14models/entrant.proto"a\n\x11GetBracketRequest\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x120\n\x07slug_id\x18\x02 \x01(\x0b2\x1d.parrygg.models.BracketSlugIdH\x00B\x0c\n\nidentifier">\n\x12GetBracketResponse\x12(\n\x07bracket\x18\x01 \x01(\x0b2\x17.parrygg.models.Bracket"(\n\x1aGetBracketTimestampRequest\x12\n\n\x02id\x18\x01 \x01(\t"M\n\x1bGetBracketTimestampResponse\x12.\n\nupdated_at\x18\x01 \x01(\x0b2\x1a.google.protobuf.Timestamp"!\n\x13ResetBracketRequest\x12\n\n\x02id\x18\x01 \x01(\t"\x16\n\x14ResetBracketResponse")\n\x1bGetBracketPlacementsRequest\x12\n\n\x02id\x18\x01 \x01(\t"M\n\x1cGetBracketPlacementsResponse\x12-\n\nplacements\x18\x01 \x03(\x0b2\x19.parrygg.models.Placement"!\n\x13StartBracketRequest\x12\n\n\x02id\x18\x01 \x01(\t"@\n\x14StartBracketResponse\x12(\n\x07bracket\x18\x01 \x01(\x0b2\x17.parrygg.models.Bracket2\x9c\x04\n\x0eBracketService\x12Y\n\nGetBracket\x12#.parrygg.services.GetBracketRequest\x1a$.parrygg.services.GetBracketResponse"\x00\x12t\n\x13GetBracketTimestamp\x12,.parrygg.services.GetBracketTimestampRequest\x1a-.parrygg.services.GetBracketTimestampResponse"\x00\x12_\n\x0cResetBracket\x12%.parrygg.services.ResetBracketRequest\x1a&.parrygg.services.ResetBracketResponse"\x00\x12w\n\x14GetBracketPlacements\x12-.parrygg.services.GetBracketPlacementsRequest\x1a..parrygg.services.GetBracketPlacementsResponse"\x00\x12_\n\x0cStartBracket\x12%.parrygg.services.StartBracketRequest\x1a&.parrygg.services.StartBracketResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.bracket_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETBRACKETREQUEST']._serialized_start = 129
    _globals['_GETBRACKETREQUEST']._serialized_end = 226
    _globals['_GETBRACKETRESPONSE']._serialized_start = 228
    _globals['_GETBRACKETRESPONSE']._serialized_end = 290
    _globals['_GETBRACKETTIMESTAMPREQUEST']._serialized_start = 292
    _globals['_GETBRACKETTIMESTAMPREQUEST']._serialized_end = 332
    _globals['_GETBRACKETTIMESTAMPRESPONSE']._serialized_start = 334
    _globals['_GETBRACKETTIMESTAMPRESPONSE']._serialized_end = 411
    _globals['_RESETBRACKETREQUEST']._serialized_start = 413
    _globals['_RESETBRACKETREQUEST']._serialized_end = 446
    _globals['_RESETBRACKETRESPONSE']._serialized_start = 448
    _globals['_RESETBRACKETRESPONSE']._serialized_end = 470
    _globals['_GETBRACKETPLACEMENTSREQUEST']._serialized_start = 472
    _globals['_GETBRACKETPLACEMENTSREQUEST']._serialized_end = 513
    _globals['_GETBRACKETPLACEMENTSRESPONSE']._serialized_start = 515
    _globals['_GETBRACKETPLACEMENTSRESPONSE']._serialized_end = 592
    _globals['_STARTBRACKETREQUEST']._serialized_start = 594
    _globals['_STARTBRACKETREQUEST']._serialized_end = 627
    _globals['_STARTBRACKETRESPONSE']._serialized_start = 629
    _globals['_STARTBRACKETRESPONSE']._serialized_end = 693
    _globals['_BRACKETSERVICE']._serialized_start = 696
    _globals['_BRACKETSERVICE']._serialized_end = 1236




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in models/image_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/game_service.proto')
_sym_db = _symbol_database.Default()
from ..models import game_pb2 as models_dot_game__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bservices/game_service.proto\x12\x10parrygg.services\x1a\x11models/game.proto"\x11\n\x0fGetGamesRequest"7\n\x10GetGamesResponse\x12#\n\x05games\x18\x01 \x03(\x0b2\x14.parrygg.models.Game2b\n\x0bGameService\x12S\n\x08GetGames\x12!.parrygg.services.GetGamesRequest\x1a".parrygg.services.GetGamesResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.game_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETGAMESREQUEST']._serialized_start = 68
    _globals['_GETGAMESREQUEST']._serialized_end = 85
    _globals['_GETGAMESRESPONSE']._serialized_start = 87
    _globals['_GETGAMESRESPONSE']._serialized_end = 142
    _globals['_GAMESERVICE']._serialized_start = 144
    _globals['_GAMESERVICE']._serialized_end = 242




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import hierarchy_service_pb2 as services_dot_hierarchy__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/hierarchy_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class HierarchyServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetEventHierarchy = channel.unary_unary('/parrygg.services.HierarchyService/GetEventHierarchy', request_serializer=services_dot_hierarchy__service__pb2.GetEventHierarchyRequest.SerializeToString, response_deserializer=services_dot_hierarchy__service__pb2.GetEventHierarchyResponse.FromString, _registered_method=True)
        self.GetPhaseHierarchy = channel.unary_unary('/parrygg.services.HierarchyService/GetPhaseHierarchy', request_serializer=services_dot_hierarchy__service__pb2.GetPhaseHierarchyRequest.SerializeToString, response_deserializer=services_dot_hierarchy__service__pb2.GetPhaseHierarchyResponse.FromString, _registered_method=True)
        self.GetBracketHierarchy = channel.unary_unary('/parrygg.services.HierarchyService/GetBracketHierarchy', request_serializer=services_dot_hierarchy__service__pb2.GetBracketHierarchyRequest.SerializeToString, response_deserializer=services_dot_hierarchy__service__pb2.GetBracketHierarchyResponse.FromString, _registered_method=True)

class HierarchyServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def GetEventHierarchy(self, request, context):
        'Retrieves the complete hierarchy structure for an event by ID or slug path.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPhaseHierarchy(self, request, context):
        'Retrieves the complete hierarchy structure for a phase by ID or slug path.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBracketHierarchy(self, request, context):
        'Retrieves the complete hierarchy structure for a bracket by ID or slug path.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_HierarchyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetEventHierarchy': grpc.unary_unary_rpc_method_handler(servicer.GetEventHierarchy, request_deserializer=services_dot_hierarchy__service__pb2.GetEventHierarchyRequest.FromString, response_serializer=services_dot_hierarchy__service__pb2.GetEventHierarchyResponse.SerializeToString), 'GetPhaseHierarchy': grpc.unary_unary_rpc_method_handler(servicer.GetPhaseHierarchy, request_deserializer=services_dot_hierarchy__service__pb2.GetPhaseHierarchyRequest.FromString, response_serializer=services_dot_hierarchy__service__pb2.GetPhaseHierarchyResponse.SerializeToString), 'GetBracketHierarchy': grpc.unary_unary_rpc_method_handler(servicer.GetBracketHierarchy, request_deserializer=services_dot_hierarchy__service__pb2.GetBracketHierarchyRequest.FromString, response_serializer=services_dot_hierarchy__service__pb2.GetBracketHierarchyResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.HierarchyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.HierarchyService', rpc_method_handlers)

class HierarchyService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def GetEventHierarchy(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.HierarchyService/GetEventHierarchy', services_dot_hierarchy__service__pb2.GetEventHierarchyRequest.SerializeToString, services_dot_hierarchy__service__pb2.GetEventHierarchyResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetPhaseHierarchy(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.HierarchyService/GetPhaseHierarchy', services_dot_hierarchy__service__pb2.GetPhaseHierarchyRequest.SerializeToString, services_dot_hierarchy__service__pb2.GetPhaseHierarchyResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetBracketHierarchy(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.HierarchyService/GetBracketHierarchy', services_dot_hierarchy__service__pb2.GetBracketHierarchyRequest.SerializeToString, services_dot_hierarchy__service__pb2.GetBracketHierarchyResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/filter.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13models/filter.proto\x12\x0eparrygg.models"0\n\x0cEventsFilter\x12\x14\n\x07user_id\x18\x01 \x01(\tH\x00\x88\x01\x01B\n\n\x08_user_id"\xa2\x01\n\x11TournamentsFilter\x12\x14\n\x07user_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08owner_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x126\n\x0cadmin_filter\x18\x03 \x01(\x0b2\x1b.parrygg.models.AdminFilterH\x02\x88\x01\x01B\n\n\x08_user_idB\x0b\n\t_owner_idB\x0f\n\r_admin_filter"3\n\x0bUsersFilter\x12\x16\n\tgamer_tag\x18\x01 \x01(\tH\x00\x88\x01\x01B\x0c\n\n_gamer_tag"Y\n\x0bAdminFilter\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x129\n\npermission\x18\x02 \x01(\x0e2%.parrygg.models.AdminFilterPermission*\xa6\x01\n\x15AdminFilterPermission\x12\x1f\n\x1bADMIN_FILTER_PERMISSION_ANY\x10\x00\x12!\n\x1dADMIN_FILTER_PERMISSION_ADMIN\x10\x01\x12#\n\x1fADMIN_FILTER_PERMISSION_MANAGER\x10\x02\x12$\n ADMIN_FILTER_PERMISSION_REPORTER\x10\x03B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.filter_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_ADMINFILTERPERMISSION']._serialized_start = 399
    _globals['_ADMINFILTERPERMISSION']._serialized_end = 565
    _globals['_EVENTSFILTER']._serialized_start = 39
    _globals['_EVENTSFILTER']._serialized_end = 87
    _globals['_TOURNAMENTSFILTER']._serialized_start = 90
    _globals['_TOURNAMENTSFILTER']._serialized_end = 252
    _globals['_USERSFILTER']._serialized_start = 254
    _globals['_USERSFILTER']._serialized_end = 305
    _globals['_ADMINFILTER']._serialized_start = 307
    _globals['_ADMINFILTER']._serialized_end = 396




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/phase.proto')
_sym_db = _symbol_database.Default()
from ..models import bracket_pb2 as models_dot_bracket__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12models/phase.proto\x12\x0eparrygg.models\x1a\x14models/bracket.proto"\xd5\x01\n\x05Phase\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x08brackets\x18\x03 \x03(\x0b2\x17.parrygg.models.Bracket\x12\x15\n\rdefault_entry\x18\x04 \x01(\x08\x121\n\x0cbracket_type\x18\x05 \x01(\x0e2\x1b.parrygg.models.BracketType\x12\x0c\n\x04name\x18\x06 \x01(\t\x12)\n\x05state\x18\x07 \x01(\x0e2\x1a.parrygg.models.PhaseState\x12\x0c\n\x04slug\x18\x08 \x01(\tJ\x04\x08\x02\x10\x03"z\n\rPhaseMutation\x126\n\x0cbracket_type\x18\x02 \x01(\x0e2\x1b.parrygg.models.BracketTypeH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x01\x88\x01\x01B\x0f\n\r_bracket_typeB\x07\n\x05_nameJ\x04\x08\x01\x10\x02"N\n\x0bPhaseSlugId\x12\x17\n\x0ftournament_slug\x18\x01 \x01(\t\x12\x12\n\nevent_slug\x18\x02 \x01(\t\x12\x12\n\nphase_slug\x18\x03 \x01(\t"]\n\x0fPhaseIdentifier\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x12.\n\x07slug_id\x18\x02 \x01(\x0b2\x1b.parrygg.models.PhaseSlugIdH\x00B\x0c\n\nidentifier*\x91\x01\n\nPhaseState\x12\x1b\n\x17PHASE_STATE_UNSPECIFIED\x10\x00\x12\x17\n\x13PHASE_STATE_PENDING\x10\x01\x12\x15\n\x11PHASE_STATE_READY\x10\x02\x12\x1b\n\x17PHASE_STATE_IN_PROGRESS\x10\x03\x12\x19\n\x15PHASE_STATE_COMPLETED\x10\x04B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.phase_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_PHASESTATE']._serialized_start = 576
    _globals['_PHASESTATE']._serialized_end = 721
    _globals['_PHASE']._serialized_start = 61
    _globals['_PHASE']._serialized_end = 274
    _globals['_PHASEMUTATION']._serialized_start = 276
    _globals['_PHASEMUTATION']._serialized_end = 398
    _globals['_PHASESLUGID']._serialized_start = 400
    _globals['_PHASESLUGID']._serialized_end = 478
    _globals['_PHASEIDENTIFIER']._serialized_start = 480
    _globals['_PHASEIDENTIFIER']._serialized_end = 573




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/slug.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11models/slug.proto\x12\x0eparrygg.models"<\n\x04Slug\x12\x0c\n\x04slug\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e2\x18.parrygg.models.SlugType"C\n\x0bMutableSlug\x12\x0c\n\x04slug\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e2\x18.parrygg.models.SlugType*j\n\x08SlugType\x12\x19\n\x15SLUG_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11SLUG_TYPE_PRIMARY\x10\x01\x12\x16\n\x12SLUG_TYPE_OUTDATED\x10\x02\x12\x14\n\x10SLUG_TYPE_CUSTOM\x10\x03B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.slug_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_SLUGTYPE']._serialized_start = 168
    _globals['_SLUGTYPE']._serialized_end = 274
    _globals['_SLUG']._serialized_start = 37
    _globals['_SLUG']._serialized_end = 97
    _globals['_MUTABLESLUG']._serialized_start = 99
    _globals['_MUTABLESLUG']._serialized_end = 166




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import match_service_pb2 as services_dot_match__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/match_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class MatchServiceStub(object):
    'MatchService provides tournament match management operations.\n    Handles match lifecycle, scoring, and result reporting.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetMatch = channel.unary_unary('/parrygg.services.MatchService/GetMatch', request_serializer=services_dot_match__service__pb2.GetMatchRequest.SerializeToString, response_deserializer=services_dot_match__service__pb2.GetMatchResponse.FromString, _registered_method=True)
        self.SetMatchResult = channel.unary_unary('/parrygg.services.MatchService/SetMatchResult', request_serializer=services_dot_match__service__pb2.SetMatchResultRequest.SerializeToString, response_deserializer=services_dot_match__service__pb2.SetMatchResultResponse.FromString, _registered_method=True)
        self.StartMatch = channel.unary_unary('/parrygg.services.MatchService/StartMatch', request_serializer=services_dot_match__service__pb2.StartMatchRequest.SerializeToString, response_deserializer=services_dot_match__service__pb2.StartMatchResponse.FromString, _registered_method=True)
        self.ResetMatch = channel.unary_unary('/parrygg.services.MatchService/ResetMatch', request_serializer=services_dot_match__service__pb2.ResetMatchRequest.SerializeToString, response_deserializer=services_dot_match__service__pb2.ResetMatchResponse.FromString, _registered_method=True)

class MatchServiceServicer(object):
    'MatchService provides tournament match management operations.\n    Handles match lifecycle, scoring, and result reporting.\n    '

    def GetMatch(self, request, context):
        'Retrieve a specific match by ID.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMatchResult(self, request, context):
        'Update match results and participant scores.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartMatch(self, request, context):
        'Start a match and change state to in-progress.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetMatch(self, request, context):
        'Reset a match to initial state, clearing results.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_MatchServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetMatch': grpc.unary_unary_rpc_method_handler(servicer.GetMatch, request_deserializer=services_dot_match__service__pb2.GetMatchRequest.FromString, response_serializer=services_dot_match__service__pb2.GetMatchResponse.SerializeToString), 'SetMatchResult': grpc.unary_unary_rpc_method_handler(servicer.SetMatchResult, request_deserializer=services_dot_match__service__pb2.SetMatchResultRequest.FromString, response_serializer=services_dot_match__service__pb2.SetMatchResultResponse.SerializeToString), 'StartMatch': grpc.unary_unary_rpc_method_handler(servicer.StartMatch, request_deserializer=services_dot_match__service__pb2.StartMatchRequest.FromString, response_serializer=services_dot_match__service__pb2.StartMatchResponse.SerializeToString), 'ResetMatch': grpc.unary_unary_rpc_method_handler(servicer.ResetMatch, request_deserializer=services_dot_match__service__pb2.ResetMatchRequest.FromString, response_serializer=services_dot_match__service__pb2.ResetMatchResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.MatchService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.MatchService', rpc_method_handlers)

class MatchService(object):
    'MatchService provides tournament match management operations.\n    Handles match lifecycle, scoring, and result reporting.\n    '

    @staticmethod
    def GetMatch(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.MatchService/GetMatch', services_dot_match__service__pb2.GetMatchRequest.SerializeToString, services_dot_match__service__pb2.GetMatchResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetMatchResult(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.MatchService/SetMatchResult', services_dot_match__service__pb2.SetMatchResultRequest.SerializeToString, services_dot_match__service__pb2.SetMatchResultResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def StartMatch(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.MatchService/StartMatch', services_dot_match__service__pb2.StartMatchRequest.SerializeToString, services_dot_match__service__pb2.StartMatchResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ResetMatch(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.MatchService/ResetMatch', services_dot_match__service__pb2.ResetMatchRequest.SerializeToString, services_dot_match__service__pb2.ResetMatchResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/request.proto')
_sym_db = _symbol_database.Default()
from ..models import user_pb2 as models_dot_user__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14models/request.proto\x12\x0eparrygg.models\x1a\x11models/user.proto"\xb1\x01\n\x07Request\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cfrom_user_id\x18\x02 \x01(\t\x12\x12\n\nto_user_id\x18\x03 \x01(\t\x12+\n\x05state\x18\x04 \x01(\x0e2\x1c.parrygg.models.RequestState\x12;\n\x10teammate_request\x18\x05 \x01(\x0b2\x1f.parrygg.models.TeammateRequestH\x00B\x06\n\x04type"\x88\x01\n\x0fRequestCreation\x12\x14\n\x0cfrom_user_id\x18\x02 \x01(\t\x12\x12\n\nto_user_id\x18\x03 \x01(\t\x12C\n\x10teammate_request\x18\x05 \x01(\x0b2\'.parrygg.models.TeammateRequestCreationH\x00B\x06\n\x04type">\n\x0fRequestMutation\x12+\n\x05state\x18\x01 \x01(\x0e2\x1c.parrygg.models.RequestState"{\n\x0fTeammateRequest\x12\x18\n\x10event_entrant_id\x18\x01 \x01(\t\x12%\n\x07to_user\x18\x02 \x01(\x0b2\x14.parrygg.models.User\x12\'\n\tfrom_user\x18\x03 \x01(\x0b2\x14.parrygg.models.User"3\n\x17TeammateRequestCreation\x12\x18\n\x10event_entrant_id\x18\x01 \x01(\t*\x80\x01\n\x0cRequestState\x12\x1d\n\x19REQUEST_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15REQUEST_STATE_PENDING\x10\x01\x12\x1a\n\x16REQUEST_STATE_ACCEPTED\x10\x02\x12\x1a\n\x16REQUEST_STATE_REJECTED\x10\x03B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.request_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_REQUESTSTATE']._serialized_start = 621
    _globals['_REQUESTSTATE']._serialized_end = 749
    _globals['_REQUEST']._serialized_start = 60
    _globals['_REQUEST']._serialized_end = 237
    _globals['_REQUESTCREATION']._serialized_start = 240
    _globals['_REQUESTCREATION']._serialized_end = 376
    _globals['_REQUESTMUTATION']._serialized_start = 378
    _globals['_REQUESTMUTATION']._serialized_end = 440
    _globals['_TEAMMATEREQUEST']._serialized_start = 442
    _globals['_TEAMMATEREQUEST']._serialized_end = 565
    _globals['_TEAMMATEREQUESTCREATION']._serialized_start = 567
    _globals['_TEAMMATEREQUESTCREATION']._serialized_end = 618
